/**
 * @since 1.0.0
 */
import { type CreateDeliveryStreamCommandInput, type CreateDeliveryStreamCommandOutput, type DeleteDeliveryStreamCommandInput, type DeleteDeliveryStreamCommandOutput, type DescribeDeliveryStreamCommandInput, type DescribeDeliveryStreamCommandOutput, type FirehoseClient, type FirehoseClientConfig, type ListDeliveryStreamsCommandInput, type ListDeliveryStreamsCommandOutput, type ListTagsForDeliveryStreamCommandInput, type ListTagsForDeliveryStreamCommandOutput, type PutRecordBatchCommandInput, type PutRecordBatchCommandOutput, type PutRecordCommandInput, type PutRecordCommandOutput, type StartDeliveryStreamEncryptionCommandInput, type StartDeliveryStreamEncryptionCommandOutput, type StopDeliveryStreamEncryptionCommandInput, type StopDeliveryStreamEncryptionCommandOutput, type TagDeliveryStreamCommandInput, type TagDeliveryStreamCommandOutput, type UntagDeliveryStreamCommandInput, type UntagDeliveryStreamCommandOutput, type UpdateDestinationCommandInput, type UpdateDestinationCommandOutput } from "@aws-sdk/client-firehose";
import type { HttpHandlerOptions, SdkError, ServiceLogger } from "@effect-aws/commons";
import { Effect, Layer } from "effect";
import type { ConcurrentModificationError, InvalidArgumentError, InvalidKMSResourceError, InvalidSourceError, LimitExceededError, ResourceInUseError, ResourceNotFoundError, ServiceUnavailableError } from "./Errors.js";
import * as Instance from "./FirehoseClientInstance.js";
interface FirehoseService$ {
    readonly _: unique symbol;
    /**
     * @see {@link CreateDeliveryStreamCommand}
     */
    createDeliveryStream(args: CreateDeliveryStreamCommandInput, options?: HttpHandlerOptions): Effect.Effect<CreateDeliveryStreamCommandOutput, SdkError | InvalidArgumentError | InvalidKMSResourceError | LimitExceededError | ResourceInUseError>;
    /**
     * @see {@link DeleteDeliveryStreamCommand}
     */
    deleteDeliveryStream(args: DeleteDeliveryStreamCommandInput, options?: HttpHandlerOptions): Effect.Effect<DeleteDeliveryStreamCommandOutput, SdkError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link DescribeDeliveryStreamCommand}
     */
    describeDeliveryStream(args: DescribeDeliveryStreamCommandInput, options?: HttpHandlerOptions): Effect.Effect<DescribeDeliveryStreamCommandOutput, SdkError | ResourceNotFoundError>;
    /**
     * @see {@link ListDeliveryStreamsCommand}
     */
    listDeliveryStreams(args: ListDeliveryStreamsCommandInput, options?: HttpHandlerOptions): Effect.Effect<ListDeliveryStreamsCommandOutput, SdkError>;
    /**
     * @see {@link ListTagsForDeliveryStreamCommand}
     */
    listTagsForDeliveryStream(args: ListTagsForDeliveryStreamCommandInput, options?: HttpHandlerOptions): Effect.Effect<ListTagsForDeliveryStreamCommandOutput, SdkError | InvalidArgumentError | LimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link PutRecordCommand}
     */
    putRecord(args: PutRecordCommandInput, options?: HttpHandlerOptions): Effect.Effect<PutRecordCommandOutput, SdkError | InvalidArgumentError | InvalidKMSResourceError | InvalidSourceError | ResourceNotFoundError | ServiceUnavailableError>;
    /**
     * @see {@link PutRecordBatchCommand}
     */
    putRecordBatch(args: PutRecordBatchCommandInput, options?: HttpHandlerOptions): Effect.Effect<PutRecordBatchCommandOutput, SdkError | InvalidArgumentError | InvalidKMSResourceError | InvalidSourceError | ResourceNotFoundError | ServiceUnavailableError>;
    /**
     * @see {@link StartDeliveryStreamEncryptionCommand}
     */
    startDeliveryStreamEncryption(args: StartDeliveryStreamEncryptionCommandInput, options?: HttpHandlerOptions): Effect.Effect<StartDeliveryStreamEncryptionCommandOutput, SdkError | InvalidArgumentError | InvalidKMSResourceError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link StopDeliveryStreamEncryptionCommand}
     */
    stopDeliveryStreamEncryption(args: StopDeliveryStreamEncryptionCommandInput, options?: HttpHandlerOptions): Effect.Effect<StopDeliveryStreamEncryptionCommandOutput, SdkError | InvalidArgumentError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link TagDeliveryStreamCommand}
     */
    tagDeliveryStream(args: TagDeliveryStreamCommandInput, options?: HttpHandlerOptions): Effect.Effect<TagDeliveryStreamCommandOutput, SdkError | InvalidArgumentError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link UntagDeliveryStreamCommand}
     */
    untagDeliveryStream(args: UntagDeliveryStreamCommandInput, options?: HttpHandlerOptions): Effect.Effect<UntagDeliveryStreamCommandOutput, SdkError | InvalidArgumentError | LimitExceededError | ResourceInUseError | ResourceNotFoundError>;
    /**
     * @see {@link UpdateDestinationCommand}
     */
    updateDestination(args: UpdateDestinationCommandInput, options?: HttpHandlerOptions): Effect.Effect<UpdateDestinationCommandOutput, SdkError | ConcurrentModificationError | InvalidArgumentError | ResourceInUseError | ResourceNotFoundError>;
}
/**
 * @since 1.0.0
 * @category constructors
 */
export declare const makeFirehoseService: Effect.Effect<FirehoseService$, never, Instance.FirehoseClientInstance>;
declare const FirehoseService_base: import("effect/Context").TagClass<FirehoseService, "@effect-aws/client-firehose/FirehoseService", FirehoseService$> & Effect.Tag.Proxy<FirehoseService, FirehoseService$> & {
    use: <X>(body: (_: FirehoseService$) => X) => [X] extends [Effect.Effect<infer A, infer E, infer R>] ? Effect.Effect<A, E, FirehoseService | R> : [X] extends [PromiseLike<infer A_1>] ? Effect.Effect<A_1, import("effect/Cause").UnknownException, FirehoseService> : Effect.Effect<X, never, FirehoseService>;
};
/**
 * @since 1.0.0
 * @category models
 */
export declare class FirehoseService extends FirehoseService_base {
    static readonly defaultLayer: Layer.Layer<FirehoseService, never, never>;
    static readonly layer: (config: FirehoseService.Config) => Layer.Layer<FirehoseService, never, never>;
    static readonly baseLayer: (evaluate: (defaultConfig: FirehoseClientConfig) => FirehoseClient) => Layer.Layer<FirehoseService, never, never>;
}
/**
 * @since 1.0.0
 */
export declare namespace FirehoseService {
    /**
     * @since 1.0.0
     */
    interface Config extends Omit<FirehoseClientConfig, "logger"> {
        readonly logger?: ServiceLogger.ServiceLoggerConstructorProps | true;
    }
}
export {};
//# sourceMappingURL=FirehoseService.d.ts.map