/**
 * @since 1.0.0
 */
import { CreateDeliveryStreamCommand, DeleteDeliveryStreamCommand, DescribeDeliveryStreamCommand, ListDeliveryStreamsCommand, ListTagsForDeliveryStreamCommand, PutRecordBatchCommand, PutRecordCommand, StartDeliveryStreamEncryptionCommand, StopDeliveryStreamEncryptionCommand, TagDeliveryStreamCommand, UntagDeliveryStreamCommand, UpdateDestinationCommand, } from "@aws-sdk/client-firehose";
import { Service } from "@effect-aws/commons";
import { Effect, Layer } from "effect";
import { AllServiceErrors } from "./Errors.js";
import * as Instance from "./FirehoseClientInstance.js";
import * as FirehoseServiceConfig from "./FirehoseServiceConfig.js";
const commands = {
    CreateDeliveryStreamCommand,
    DeleteDeliveryStreamCommand,
    DescribeDeliveryStreamCommand,
    ListDeliveryStreamsCommand,
    ListTagsForDeliveryStreamCommand,
    PutRecordCommand,
    PutRecordBatchCommand,
    StartDeliveryStreamEncryptionCommand,
    StopDeliveryStreamEncryptionCommand,
    TagDeliveryStreamCommand,
    UntagDeliveryStreamCommand,
    UpdateDestinationCommand,
};
/**
 * @since 1.0.0
 * @category constructors
 */
export const makeFirehoseService = Effect.gen(function* () {
    const client = yield* Instance.FirehoseClientInstance;
    return Service.fromClientAndCommands(client, commands, {
        errorTags: AllServiceErrors,
        resolveClientConfig: FirehoseServiceConfig.toFirehoseClientConfig,
    });
});
/**
 * @since 1.0.0
 * @category models
 */
export class FirehoseService extends Effect.Tag("@effect-aws/client-firehose/FirehoseService")() {
    static defaultLayer = Layer.effect(this, makeFirehoseService).pipe(Layer.provide(Instance.layer));
    static layer = (config) => Layer.effect(this, makeFirehoseService).pipe(Layer.provide(Instance.layer), Layer.provide(FirehoseServiceConfig.setFirehoseServiceConfig(config)));
    static baseLayer = (evaluate) => Layer.effect(this, makeFirehoseService).pipe(Layer.provide(Layer.effect(Instance.FirehoseClientInstance, Effect.map(FirehoseServiceConfig.toFirehoseClientConfig, evaluate))));
}
//# sourceMappingURL=FirehoseService.js.map