import { ServiceLogger } from "@effect-aws/commons";
import { Effect, FiberRef, Layer } from "effect";
import { dual } from "effect/Function";
import { globalValue } from "effect/GlobalValue";
/**
 * @since 1.0.0
 * @category firehose service config
 */
const currentFirehoseServiceConfig = globalValue("@effect-aws/client-firehose/currentFirehoseServiceConfig", () => FiberRef.unsafeMake({}));
/**
 * @since 1.0.0
 * @category firehose service config
 */
export const withFirehoseServiceConfig = dual(2, (effect, config) => Effect.locally(effect, currentFirehoseServiceConfig, config));
/**
 * @since 1.0.0
 * @category firehose service config
 */
export const setFirehoseServiceConfig = (config) => Layer.locallyScoped(currentFirehoseServiceConfig, config);
/**
 * @since 1.0.0
 * @category adapters
 */
export const toFirehoseClientConfig = Effect.gen(function* () {
    const { logger: serviceLogger, ...config } = yield* FiberRef.get(currentFirehoseServiceConfig);
    const logger = serviceLogger === true
        ? yield* ServiceLogger.toClientLogger(ServiceLogger.defaultServiceLogger)
        : (serviceLogger ? yield* ServiceLogger.toClientLogger(ServiceLogger.make(serviceLogger)) : undefined);
    return { logger, ...config };
});
//# sourceMappingURL=FirehoseServiceConfig.js.map